@@ -14,7 +14,7 @@
 #' \emph{MM/dd/yyyy HH:mm}.
 #'
 #' @param data_product specifies the data product to be returned.  See
-#' \href{https://tidesandcurrents.noaa.gov/api/}{CO-OPS API Documentation} for
+#' \href{https://api.tidesandcurrents.noaa.gov/api/prod/}{CO-OPS API Documentation} for
 #' the available data products.
 #'
 #' @param units a character string specifying if the data should be returned
@@ -27,7 +27,7 @@
 #' specified station.  The default is \code{'gmt'}
 #'
 #' @param datum a character string indicating the datum that should be returned.
-#' See \href{https://tidesandcurrents.noaa.gov/api/}{CO-OPS API Documentation}
+#' See \href{https://api.tidesandcurrents.noaa.gov/api/prod/}{CO-OPS API Documentation}
 #' for the available datums.
 #'
 #' @param interval a character string that specifies the interval for which
@@ -36,7 +36,7 @@
 #' \code{'hilo'}.  The retrieval  time period specified by \strong{start_date}
 #' and \strong{end_date} to create restrictions on the intervals that can be
 #' returned. See
-#' \href{https://tidesandcurrents.noaa.gov/api/}{CO-OPS API Documentation} for
+#' \href{https://api.tidesandcurrents.noaa.gov/api/prod/}{CO-OPS API Documentation} for
 #' details
 #'
 #' @param bin the bin number for the indicated currents station. If a bin is not
@@ -67,7 +67,7 @@ query_coops_data <- function(station_id,
                              interval = NULL,
                              bin = NULL) {
 
-    base_url <- "https://tidesandcurrents.noaa.gov/api/datagetter"
+    base_url <- "https://api.tidesandcurrents.noaa.gov/api/prod/datagetter"
 
     ## Create a list of all params.
     query_params <- list(station = station_id,
